import {Component, inject, OnInit} from "@angular/core";
import {FormControl, FormGroup, ReactiveFormsModule, Validators} from "@angular/forms";
import {TodoService} from "./todo.service";
import {Router} from "@angular/router";


@Component({
  standalone: true,
  selector: 'app-add-todo',
  imports: [
    ReactiveFormsModule,
  ],
  template: `
    <form [formGroup]="form" (ngSubmit)="submit()" class="form-group mx-auto" style="width: 50%;">
      <div class="mb-3">
        <label for="title" class="form-label">Title:</label>
        <input type="text" id="title" name="title" formControlName="title" class="form-control col-md-6" style="width: 50%;">
      </div>
      <div class="mb-3">
        <label for="dueDate" class="form-label">Due Date:</label>
        <input type="date" id="dueDate" name="dueDate" formControlName="dueDate" class="form-control col-md-6" style="width: 50%;" [value]="defaultDate">
      </div>
      <div class="mb-3">
        <label for="category" class="form-label">Category:</label>
        <input type="text" id="category" name="category" formControlName="category" class="form-control col-md-6" style="width: 50%;">
      </div>
      <button type="submit" class="btn btn-primary">Add</button>
    </form>
  `
})
export class AddTodoComponent implements OnInit {
  form!: FormGroup;

  todoService: TodoService = inject(TodoService);

  router: Router = inject(Router);

  defaultDate!: Date;

  errorMsg: string = '';

  ngOnInit() {
    const today = new Date();
    const tomorrow = new Date(today);
    tomorrow.setDate(today.getDate() + 1);

    this.form = new FormGroup({
      title: new FormControl('', [Validators.required]),
      dueDate: new FormControl(tomorrow.toISOString().split('T')[0], [Validators.required]),
      category: new FormControl('', [Validators.required]),
    });
  }

  submit() {
    const newTodo = {
      title: this.form.get('title')?.value,
      dueDate: this.form.get('dueDate')?.value,
      category: this.form.get('category')?.value,
    }

    let message = this.validateTodo(newTodo)
    if (message) {
      this.router.navigate([], {queryParams: {message: message, error: true}});
      return;
    }

    this.todoService.add(newTodo);
    this.router.navigate(['/todos'], {queryParams: {message: 'Todo added successfully'}});
  }

  private validateTodo(newTodo: { dueDate: any; title: any; category: any }) {
    if (!newTodo.title) {
      return 'Title is required';
    } else if (!newTodo.dueDate) {
      return 'Due Date is required';
    } else if (!newTodo.category) {
      return 'Category is required';
    }

    return
  }
}
