import {Component, inject, OnInit} from "@angular/core";
import {TodoService} from "../todo.service";
import {Todo} from "../todo";
import {NgForOf, NgIf} from "@angular/common";
import {TableFilterComponent} from "./table-filter.component";
import {SettingsService} from "../../settings/settings.service";
import {Router} from "@angular/router";


@Component({
  selector: 'app-todo',
  templateUrl: './todo-table.component.html',
  imports: [
    NgForOf,
    TableFilterComponent,
    NgIf,
  ],
  standalone: true
})
export class TodoTableComponent implements OnInit {
  todoService: TodoService = inject(TodoService);

  settingsService: SettingsService = inject(SettingsService);

  _todos: Todo[] = [];

  isFiltered: boolean = false;

  router: Router = inject(Router);

  ngOnInit() {
    this.todos = this.todoService.todos;
  }

  deleteTodo(todo: Todo) {
    this.todoService.delete(todo);

    this.router.navigate([], { queryParams: { message: 'Todo deleted' }});
  }

  toggleCompleted(todo: Todo) {
    todo.completed = !todo.completed;

    this.todoService.set(this._todos);
    this.todos = this.todoService.todos;
  }

  updateFilter(filter: string) {
    this.isFiltered = filter !== '';

    this.todos = this.todoService.todos.filter(todo => todo.category.toLowerCase().includes(filter.toLowerCase()));
  }

  get displayDeleteButton(): boolean {
    return this.settingsService.settings.displayDeleteButton
  }

  set todos(todos: Todo[]) {
    if (this.settingsService.settings.sortTodos) {
      todos = todos.sort((a, b) => Number(a.completed) - Number(b.completed));
    }
    this._todos = todos;
  }
}
